UdpSocket

Struct UdpSocket 

pub struct UdpSocket { /* private fields */ }
Async UDP datagram socket.

Implementations

Source

impl UdpSocket

pub fn bind(addr: SocketAddr) -> Result<Self>

Bind a UDP socket to addr.

Creates a SOCK_DGRAM socket, binds to addr, sets non-blocking, and registers with the reactor for both read and write readiness.

pub fn local_addr(&self) -> Result<SocketAddr>

Return the local address the socket is bound to.

pub fn send_to<'a>( &'a self, buf: &'a [u8], target: SocketAddr, ) -> SendToFuture<'a>

Return a future that sends buf to target and resolves to the number of bytes sent.

pub fn recv_from<'a>(&'a self, buf: &'a mut [u8]) -> RecvFromFuture<'a>

Return a future that receives a datagram into buf and resolves to (bytes_received, sender_addr).