Interval

Struct Interval 

pub struct Interval { /* private fields */ }
Periodic timer created by interval.

Implementations

Source

impl Interval

pub fn tick(&mut self) -> TickFuture<'_>

Returns a future that resolves at the next tick deadline.

If ticks were missed the future resolves immediately and returns the deadline of the missed tick that is now being reported.